Welcome to django-seo2’s documentation! — django-seo2 1.0 documentation

# Welcome to django-seo2’s documentation!

Django-seo2 is a Django based framework, allowing you to manage SEO (Search Engine Optimisation) metadata.

# First steps

- Background
- Installation
- Tutorial
- 60 second tutorial for Django experts

# Reference

- Reference manual
- Guide for site administrators

# More information

- django-seo2 contributors’ guide

# Indices and tables

- Welcome to django-seo2’s documentation!
- Index
- Module Index
- Search Page